# Generated by Django 2.2.6 on 2019-12-23 08:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('transaction', '0007_transactionsenderbeneficiary'),
    ]

    operations = [
        migrations.DeleteModel(
            name='TransactionSenderBeneficiary',
        ),
    ]
