# Generated by Django 2.2.6 on 2019-12-21 08:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('transaction', '0003_auto_20191221_1643'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='creditpartyidentity',
            options={'verbose_name': 'Credit Party Identity'},
        ),
        migrations.AlterField(
            model_name='transaction',
            name='creation_date',
            field=models.DateTimeField(auto_now=True, max_length=50, verbose_name='Creation date in HTTP format'),
        ),
        migrations.AlterField(
            model_name='transaction',
            name='retail_rate',
            field=models.DecimalField(blank=True, decimal_places=15, max_digits=15, verbose_name='Retail rate'),
        ),
    ]
