# Generated by Django 2.2.6 on 2019-12-21 08:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('transaction', '0004_auto_20191221_1656'),
    ]

    operations = [
        migrations.AlterField(
            model_name='transaction',
            name='retail_rate',
            field=models.DecimalField(blank=True, decimal_places=15, max_digits=15, null=True, verbose_name='Retail rate'),
        ),
        migrations.AlterField(
            model_name='transaction',
            name='wholesale_fx_rate',
            field=models.DecimalField(blank=True, decimal_places=15, max_digits=15, null=True, verbose_name='Wholesale FX rate'),
        ),
    ]
