# Generated by Django 2.2.6 on 2019-12-21 08:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('beneficiary', '0002_auto_20191221_1611'),
    ]

    operations = [
        migrations.AlterField(
            model_name='beneficiary',
            name='id_delivery_date',
            field=models.DateField(blank=True, max_length=50, null=True, verbose_name='ID delivery date in ISO 8601 format'),
        ),
    ]
