# Generated by Django 2.2.6 on 2019-12-23 08:17

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('beneficiary', '0003_auto_20191221_1619'),
        ('sender', '0002_auto_20191221_1611'),
        ('transaction', '0006_auto_20191221_1659'),
    ]

    operations = [
        migrations.CreateModel(
            name='TransactionSenderBeneficiary',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('beneficiary', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='beneficiary.Beneficiary', verbose_name='beneficiary entity in this transaction')),
                ('sender', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='sender.Sender', verbose_name='sender entity in this transaction')),
            ],
        ),
    ]
