# Generated by Django 2.2.6 on 2019-12-21 08:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('transaction', '0002_auto_20191221_1340'),
    ]

    operations = [
        migrations.CreateModel(
            name='CreditPartyIdentity',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('msisdn', models.CharField(max_length=50, verbose_name='MSISDN in international format')),
                ('bank_account_number', models.CharField(max_length=50, verbose_name='Bank account number')),
                ('swift_bic_code', models.CharField(max_length=50, verbose_name='SWIFT-BIC code')),
            ],
            options={
                'db_table': 'Credit Party Identity',
            },
        ),
        migrations.AlterField(
            model_name='transaction',
            name='creation_date',
            field=models.DateTimeField(auto_created=True, max_length=50, verbose_name='Creation date in HTTP format'),
        ),
        migrations.AlterField(
            model_name='transaction',
            name='expiration_date',
            field=models.DateTimeField(blank=True, max_length=50, null=True, verbose_name='Expiration date in HTTP format'),
        ),
        migrations.AlterField(
            model_name='transaction',
            name='wholesale_fx_rate',
            field=models.DecimalField(blank=True, decimal_places=15, max_digits=15, verbose_name='Wholesale FX rate'),
        ),
    ]
